@@ -8,6 +8,9 @@ import jsii
 import publication
 import typing_extensions
 
+import aws_cdk.aws_apigateway._jsii
+import aws_cdk.aws_events._jsii
+import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.core._jsii
 import cloudcomponents.cdk_secret_key._jsii
@@ -15,9 +18,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-stripe-webhook",
-    "1.29.0",
+    "1.30.0",
     __name__[0:-6],
-    "cdk-stripe-webhook@1.29.0.jsii.tgz",
+    "cdk-stripe-webhook@1.30.0.jsii.tgz",
 )
 
 __all__ = [
